/* global jQuery */
jQuery(function($) {
    $('.korean-group input').on('change', function(e) {
        var validate_code = [1,3,7,1,3,7,1,3,5.5];
       // TODO:
        // 10 - sum( 1 3 7 1 3 7 1 3 5.5 ) % 10
    });

});