div.korean-group {
    display: flex;
}

.korean-group .korean {
    padding: 0 7px;
    border: 0;
}

.korean-group .form-inline {
    display: inline-flex;
    margin: auto;
}

.korean-group .form-control {
    border-width: 1px 0;
    border-radius: 0;
    vertical-align: top;

    padding-left: 15px;
    padding-right: 15px;

    overflow: visible;
}

.is-invalid .korean-group {
    border-color: #dc3545;
}

.is-valid .korean-group {
    border-color: #28a745;
}

.is-invalid .form-control.korean-group~.invalid-feedback {
    display: block;
}
