{% spaceless %}
<div class="form-group form-inline jumin-group" id="{{ widget.name }}">
    <input type="{{ widget.type }}" size="6"
           class="form-control jumin-left"
           name="{{ widget.name }}"{% if widget.value != None %}
           value="{{ widget.value.0|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}>
    <div class="form-control"> - </div>
    <input type="{{ widget.type }}" size="7"
           class="form-control jumin-right"
           name="{{ widget.name }}"{% if widget.value != None %}
           value="{{ widget.value.1|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}>
</div>
{% endspaceless %}